local ldb = LibStub:GetLibrary("LibDataBroker-1.1")

local addon = LibStub("AceAddon-3.0"):NewAddon("Broker2FuBar", "AceConsole-3.0", "AceHook-3.0")

addon.registry = {} -- required here for options

function addon:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("Broker2FuBarDB", {
		profile = {
			objects = {
				['*'] = true,
			},
		},
	})

	LibStub("AceConfig-3.0"):RegisterOptionsTable(self.name, self.options)
			
	self.objectOptionsMetaTable = { __index = self.objectOptionsTemplate }
	
	self.fubared = {}

	for name, data_object in ldb:DataObjectIterator() do
		self:RegisterObject(name, data_object)
	end

	ldb.RegisterCallback(self, "LibDataBroker_DataObjectCreated")
end

function addon:LibDataBroker_DataObjectCreated(event, name, data_object)
	self:RegisterObject(name, data_object)
end

function addon:RegisterObject(name, data_object)
	if not self.registry[name] then
		self.registry[name] = data_object.label or name
	end
	if self:IsObjectEnabled(name) then
		self:OnObjectEnable(name, data_object)
	end
end

function addon:IsObjectEnabled(name)
	return self.db.profile.objects[name]
end

function addon:EnableObject(name, value)
	if value and not self.db.profile.objects[name] then
		self.db.profile.objects[name] = true
		self:OnObjectEnable(name)
	elseif not value and self.db.profile.objects[name] then
		self.db.profile.objects[name] = false
		self:OnObjectDisable(name)
	end
end

function addon:OnObjectEnable(name, data_object)
	local fu = self:FuBarize(name, data_object)
	if not fu:IsEnabled() then
		fu:Enable()
	end
end

function addon:OnObjectDisable(name)
	local fu = self.fubared[name]
	if not fu then return end
	if fu:IsEnabled() then
		fu:Disable()	
	end
end

function addon:FuBarize(name, data_object)
	if self.fubared[name] then 
		return self.fubared[name]
	end
	data_object = data_object or ldb:GetDataObjectByName(name)
	
	local fu = LibStub("AceAddon-3.0"):NewAddon(name .. "_B2Fu", "LibFuBarPlugin-Mod-3.0")
	fu.data_object = data_object
	fu.db = self.db:RegisterNamespace(name, {profile={}})

	fu:SetFuBarOption('tooltipType', data_object.tooltip and 'Custom' or 'GameTooltip')
	fu:SetFuBarOption('configType', 'AceConfigDialog-3.0')
	fu:SetFuBarOption('aceConfig30', self.name)
	
	self.objectOptions[name] = setmetatable({name = name, handler = fu}, self.objectOptionsMetaTable)
	
	function fu:OnUpdateFuBarText()
		self:SetFuBarText(data_object.text)
	end
	function fu:OnUpdateFuBarIcon()
		-- this isn't an official fubar method, note
		self:SetFuBarOption('iconPath', data_object.icon)
	end
	function fu:OnFuBarClick(button)
		if data_object.OnClick then
			data_object.OnClick(self:GetPanel(), button)
		end
	end
	function fu:OnFuBarEnter()
		if data_object.OnEnter then
			data_object.OnEnter(self:GetPanel())
		end
	end
	function fu:OnFuBarLeave(button)
		if data_object.OnLeave then
			data_object.OnLeave(self:GetPanel())
		end
	end
	function fu:OnUpdateFuBarTooltip()
		if data_object.tooltip then
			if data_object.tooltiptext then
				data_object.tooltip:SetText(data_object.tooltiptext)
			end
			data_object.tooltip:Show()
		elseif data_object.OnTooltipShow then
			data_object.OnTooltipShow(GameTooltip)
		elseif data_object.tooltiptext then
			GameTooltip:SetText(data_object.tooltiptext)
		end
	end	
	function fu:OnEnable()
		ldb.RegisterCallback(self, "LibDataBroker_AttributeChanged_"..name.."_text", "OnUpdateFuBarText")
		ldb.RegisterCallback(self, "LibDataBroker_AttributeChanged_"..name.."_icon", "OnUpdateFuBarIcon")
		ldb.RegisterCallback(self, "LibDataBroker_AttributeChanged_"..name.."_tooltiptext", "OnUpdateFuBarTooltip")
		self:OnUpdateFuBarIcon()
	end
	
	-- OnEnable is defined after the addon has been enabled
	if fu.enabledState then
		fu:OnEnable()
	end
	
	self.fubared[name] = fu
	return fu
end

