local addon = LibStub("AceAddon-3.0"):GetAddon("Broker2FuBar")

addon.objectOptions = {}
addon.options = {
	type = 'group',
	name = addon.name,
	handler = addon,
	args = {
		general = {
			order = 100,
			name = 'General',
			desc = 'General settings',
			type = 'group',
			args = {	
				enable = {
					name = 'Enable objects',
					desc = 'Only the selected LibDataBroker objets are wrapper into FuBar plugins.',
					type = 'multiselect',
					get = function(info, name)
						return info.handler:IsObjectEnabled(name)
					end,
					set = function(info, name, value)
						info.handler:EnableObject(name, value)
					end,
					values = addon.registry,
				},
			}
		},
		plugin = {
			order = 110,
			name = 'Plugins',
			desc = 'Individual plugin configuration',
			type = 'group',
			args = addon.objectOptions
		}
	},
}

-- What follow is an adaptation from FBP's config table

local SHOW_FUBAR_ICON = "Show FuBar icon"
local SHOW_FUBAR_ICON_DESC = "Show the FuBar plugin's icon on the panel."
local SHOW_FUBAR_TEXT = "Show FuBar text"
local SHOW_FUBAR_TEXT_DESC = "Show the FuBar plugin's text on the panel."
local POSITION_ON_FUBAR = "Position on FuBar"
local POSITION_ON_FUBAR_DESC = "Position the FuBar plugin on the panel."
local POSITION_LEFT = "Left"
local POSITION_RIGHT = "Right"
local POSITION_CENTER = "Center"
local ATTACH_PLUGIN_TO_MINIMAP = "Attach FuBar plugin to minimap"
local ATTACH_PLUGIN_TO_MINIMAP_DESC = "Attach the FuBar plugin to the minimap instead of the panel."

if GetLocale() == "zhCN" then
	SHOW_FUBAR_ICON = "??FuBar??"
	SHOW_FUBAR_ICON_DESC = "??????FuBar?????."
	SHOW_FUBAR_TEXT = "??FuBar??"
	SHOW_FUBAR_TEXT_DESC = "??????Fubar??????"
	POSITION_ON_FUBAR = "??"
	POSITION_ON_FUBAR_DESC = "FuBar?????????."
	POSITION_LEFT = "??"
	POSITION_RIGHT = "??"
	POSITION_CENTER = "??"
	ATTACH_PLUGIN_TO_MINIMAP = "??????"
	ATTACH_PLUGIN_TO_MINIMAP_DESC = "??????????????????."
elseif GetLocale() == "zhTW" then
	SHOW_FUBAR_ICON = "????"
	SHOW_FUBAR_ICON_DESC = "???????????"
	SHOW_FUBAR_TEXT = "????"
	SHOW_FUBAR_TEXT_DESC = "???????????"
	POSITION_ON_FUBAR = "??"
	POSITION_ON_FUBAR_DESC = "??????????"
	POSITION_LEFT = "??"
	POSITION_RIGHT = "??"
	POSITION_CENTER = "??"
	ATTACH_PLUGIN_TO_MINIMAP = "??????"
	ATTACH_PLUGIN_TO_MINIMAP_DESC = "???????????????????"
elseif GetLocale() == "koKR" then
	SHOW_FUBAR_ICON = "FuBar ??? ??"
	SHOW_FUBAR_ICON_DESC = "FuBar ??? ???? ???? ?????."
	SHOW_FUBAR_TEXT = "FuBar ??? ??"
	SHOW_FUBAR_TEXT_DESC = "FuBar ??? ???? ???? ?????."
	POSITION_ON_FUBAR = "FuBar ??"
	POSITION_ON_FUBAR_DESC = "?? ?? FuBar ????? ??? ?????."
	POSITION_LEFT = "??"
	POSITION_RIGHT = "??"
	POSITION_CENTER = "??"
	ATTACH_PLUGIN_TO_MINIMAP = "FuBar ???? ??? ??"
	ATTACH_PLUGIN_TO_MINIMAP_DESC = "FuBar ????? ?? ?? ???? ?????."
elseif GetLocale() == "frFR" then
	SHOW_FUBAR_ICON = "Afficher l'icône FuBar"
	SHOW_FUBAR_ICON_DESC = "Affiche l'icône du plugin FuBar sur le panneau."
	SHOW_FUBAR_TEXT = "Afficher le texte FuBar"
	SHOW_FUBAR_TEXT_DESC = "Affiche le texte du plugin FuBar sur le panneau."
	POSITION_ON_FUBAR = "Position sur FuBar"
	POSITION_ON_FUBAR_DESC = "Position du plugin FuBar sur le panneau."
	POSITION_LEFT = "Gauche"
	POSITION_RIGHT = "Droite"
	POSITION_CENTER = "Centre"
	ATTACH_PLUGIN_TO_MINIMAP = "Attacher le plugin FuBar sur la minicarte"
	ATTACH_PLUGIN_TO_MINIMAP_DESC = "Attache le plugin FuBar sur la minicarte au lieu du panneau."
end

addon.objectOptionsTemplate = {
	type = 'group',
	hidden = function(info)
		return not info.handler:IsEnabled()
	end,
	args = {
		icon = {
			type = 'toggle',
			name = SHOW_FUBAR_ICON,
			desc = SHOW_FUBAR_ICON_DESC,
			set = "ToggleFuBarIconShown",
			get = "IsFuBarIconShown",
			hidden = function(info)
				return not info.handler.data_object.icon or not info.handler.data_object.text or info.handler:IsDisabled() or info.handler:IsFuBarMinimapAttached()
			end,
			order = -13.7,
		}, 
		text = {
			type = 'toggle',
			name = SHOW_FUBAR_TEXT,
			desc = SHOW_FUBAR_TEXT_DESC,
			set = "ToggleFuBarTextShown",
			get = "IsFuBarTextShown",
			hidden = function(info)
				return not info.handler.data_object.icon or not info.handler.data_object.text or info.handler:IsDisabled() or info.handler:IsFuBarMinimapAttached()
			end,
			order = -13.6,
		},
		position = {
			type = 'select',
			name = POSITION_ON_FUBAR,
			desc = POSITION_ON_FUBAR_DESC,
			values = {
				LEFT = POSITION_LEFT,
				CENTER = POSITION_CENTER,
				RIGHT = POSITION_RIGHT
			},
			get = function(info)
				local self = info.handler
				return self:GetPanel() and self:GetPanel():GetPluginSide(self)
			end,
			set = function(info, value)
				local self = info.handler
				if self:GetPanel() then
					self:GetPanel():SetPluginSide(self, value)
				end
			end,
			hidden = function(info)
				return info.handler:IsFuBarMinimapAttached() or info.handler:IsDisabled()
			end,
			order = -13.2,
		},
		minimapAttach = {
			type = 'toggle',
			name = ATTACH_PLUGIN_TO_MINIMAP,
			desc = ATTACH_PLUGIN_TO_MINIMAP_DESC,
			get = "IsFuBarMinimapAttached",
			set = "ToggleFuBarMinimapAttached",
			hidden = function(info)
				return not info.handler.data_object.OnClick or info.handler:IsDisabled()
			end,
			order = -13.1,
		},
	}
}
